@@ -16,15 +16,26 @@ def knockout(values):
     field_names = get_fields(values[0])
     return ko(values, field_names)
 
-def knockout_data(values, name=None):
+def knockout_data(values, args=None):
     """
 
     """
     if not values:
         return ''
 
+    name = None
+    safe = False
+
+    if args:
+        arg_list = [arg.strip() for arg in args.split(',')]
+        if len(arg_list) > 1:
+            safe = True
+        else:
+            safe = False
+        name = arg_list[0]
+
     field_names = get_fields(values[0])
-    return koData(values, field_names, name)
+    return koData(values, field_names, name, safe)
 
 def knockout_model(values):
     """
